@@ -10,7 +10,6 @@
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QUrl>
-#include <QAudioRecorder>
 #include <QCommandLineParser>
 #include <QQuickStyle>
 #include <QtQml>
@@ -20,18 +19,17 @@
 #include <KLocalizedString>
 
 #include "about.h"
-#include "recordingmodel.h"
-#include "utils.h"
 #include "audioplayer.h"
-#include "audiorecorder.h"
 #include "audioprober.h"
+#include "audiorecorder.h"
+#include "recording.h"
+#include "recordingmodel.h"
 #include "settingsmodel.h"
+#include "utils.h"
 #include "version.h"
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    
     // set default style
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
@@ -50,7 +48,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                          QStringLiteral(KRECORDER_VERSION_STRING),
                          QStringLiteral("Audio recorder"),
                          KAboutLicense::GPL,
-                         i18n("© 2020-2022 KDE Community"));
+                         i18n("© 2020-2024 KDE Community"));
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Jonah Brüchert"), QString(), QStringLiteral("jbb@kaidan.im"));
     KAboutData::setApplicationData(aboutData);
@@ -59,25 +57,29 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.addVersionOption();
     parser.process(app);
 
-    // pre-initialize settings model to apply settings to the AudioRecorder instance
-    SettingsModel::instance();
-
     qmlRegisterType<Recording>("KRecorder", 1, 0, "Recording");
     qmlRegisterType<AudioProber>("KRecorder", 1, 0, "AudioProber");
     qmlRegisterSingletonType<Utils>("KRecorder", 1, 0, "Utils", [] (QQmlEngine *, QJSEngine *) -> QObject* {
         return new Utils;
     });
-    qmlRegisterSingletonType<SettingsModel>("KRecorder", 1, 0, "AudioPlayer", [] (QQmlEngine *, QJSEngine *) -> QObject* {
-       return AudioPlayer::instance();
+
+    // pre-initialize settings model to apply settings to the AudioRecorder instance
+    SettingsModel::instance();
+
+    qmlRegisterSingletonType<AudioPlayer>("KRecorder", 1, 0, "AudioPlayer", [] (QQmlEngine *, QJSEngine *) -> QObject* {
+        return AudioPlayer::instance();
     });
-    qmlRegisterSingletonType<SettingsModel>("KRecorder", 1, 0, "AudioRecorder", [] (QQmlEngine *, QJSEngine *) -> QObject* {
-       return AudioRecorder::instance();
+
+    qmlRegisterSingletonType<AudioRecorder>("KRecorder", 1, 0, "AudioRecorder", [] (QQmlEngine *, QJSEngine *) -> QObject* {
+        return AudioRecorder::instance();
     });
+
     qmlRegisterSingletonType<RecordingModel>("KRecorder", 1, 0, "RecordingModel", [] (QQmlEngine *, QJSEngine *) -> QObject* {
         return RecordingModel::instance();
     });
+
     qmlRegisterSingletonType<SettingsModel>("KRecorder", 1, 0, "SettingsModel", [] (QQmlEngine *, QJSEngine *) -> QObject* {
-       return SettingsModel::instance();
+        return SettingsModel::instance();
     });
 
     qmlRegisterSingletonInstance("KRecorder", 1, 0, "AboutType", &AboutType::instance());
